"""Base/interface of each module."""
from abc import ABC
from PySide2 import QtGui

HEADLINE_FONT = QtGui.QFont()
HEADLINE_FONT.setFamily("Arial")
HEADLINE_FONT.setPointSize(12)
HEADLINE_FONT.setWeight(100)


class ModuleBase(ABC):
    """Interface for SOI-modules."""

    type = None

    def __init__(self):
        if self.type is None:
            raise NotImplementedError

    def get_size(self):
        """Abstract method, should be implemented by derived class."""
        raise NotImplementedError

    def set_pos(self, pos):
        """Abstract method, should be implemented by derived class."""
        raise NotImplementedError

    def render_onto_pdf(self):
        """Abstract method, should be implemented by derived class."""
        raise NotImplementedError

    def get_data(self):
        """Abstract method, should be implemented by derived class."""
        raise NotImplementedError

    @staticmethod
    def get_user_friendly_name():
        """Abstract method, should be implemented by derived class."""
        raise NotImplementedError

    @staticmethod
    def get_icon():
        """Abstract method, should be implemented by derived class."""
        raise NotImplementedError
